#region Copyright Syncfusion Inc. 2001 - 2016
//
//  Copyright Syncfusion Inc. 2001 - 2016. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms;
using System.Data.EntityClient;
using System.Data.Common;
using Syncfusion.Windows.Forms.Grid.Grouping;
using System.Linq;
using System.IO;
using System.Data.SqlClient;
using Syncfusion.Grouping;
using DemoCommon.Grid;
using Syncfusion.Windows.Forms.Grid;
using System.Text.RegularExpressions;

namespace Entity_Framework
{
    /// <summary>
    /// Summary description for Form1.
    /// </summary>
    public partial class Form1 : GridDemoForm
    {
        #region "API Definitions"

        private NorthwindGridEntities db;
        static string str = "Data Source=" + FindFile("NorthwindwithImage.sdf");
        public readonly static string conString = str;
        public List<Customers> customer = new List<Customers>();// = GetAllOrders().ToList<Customers>();

        #endregion 

        #region "Constructor"

        public Form1()
        {
            //
            // Required for Windows Form Designer support
            //
            InitializeComponent();
            this.SampleCustomization();
        }
        
        #endregion

        #region "sample Customization"
        /// <summary>
        /// Illustrates binding a datasource to theGridGroupingControlthrough an Entity Data Model.
        /// </summary>
        private void SampleCustomization()
        {
            try
            {
                //Create a connection object for entity connection.
                EntityConnection con = new EntityConnection("name=NorthwindGridEntities");
                con.StoreConnection.ConnectionString = conString;
                db = new NorthwindGridEntities(con);
                //this.gridDataBoundGrid1.DataSource = GetAllOrders().ToList<Customers>();
                customer = GetAllOrders().ToList<Customers>();
                this.gridDataBoundGrid1.DataSource = customer;    
            }
            catch (SqlException)
            {
                this.Close();
            }
            catch (Exception err)
            {
                MessageBox.Show("Error in Connection. " + err.Message);
                Application.Exit();
            }
        }

   
       
        #endregion

        #region "Sample Grid Settings"

        /// <summary>
        /// GridGrouping control getting started customization.
        /// </summary>

        private void SetHeaderText(GridColumnDescriptorCollection columns)
        {
            foreach (GridColumnDescriptor col in columns)
            {
                Regex rex = new Regex(@"\p{Lu}");
                int index = rex.Match(col.MappingName.Substring(1)).Index;
                string name = "";
                while (index > 0)
                {
                    name += col.MappingName.Substring(0, index + 1) + " ";
                    string secondName = col.MappingName.Substring(index + 1);
                    index = rex.Match(secondName.Substring(1)).Index;
                    while (index > 0)
                    {
                        name += secondName.Substring(0, index + 1) + " ";
                        index = rex.Match(col.MappingName.Substring(name.Replace(" ", "").Length).Substring(1)).Index;
                    }
                }
                name += col.MappingName.Substring(name.Replace(" ", "").Length);
                col.HeaderText = name;
            }
        }
        #endregion

        #region "DataBase"

        /// <summary>
        /// Get the customer table from NorthWind database.
        /// </summary>
        /// <returns>Customers details.</returns>
        private IQueryable<Customers> GetAllCustomers()
        {
            var customers = from c in db.Customers
                            select c;
            return customers;
        }

        /// <summary>
        /// Get the customer table from NorthWind database.
        /// </summary>
        /// <returns>Customers details.</returns>
        private IQueryable<Customers> GetAllOrders()
        {
            var order = from o in db.Customers
                        orderby o.CustomerID ascending
                        select o;
            return order;
        }

        #region Find
        /// <summary>
        /// Get the path of image file.
        /// </summary>
        /// <param name="bitmapName">ImageFile name.</param>
        /// <returns>ImageFile location.</returns>
        private static string FindFile(string fileName)
        {
            // Check both in parent folder and Parent\Data folders.
            //string dataFileName = @"Common\Data\" + fileName;
            string dataFileName = @"Common\Data\" + fileName;
            for (int n = 0; n < 12; n++)
            {
                if (System.IO.File.Exists(fileName))
                {
                    return new FileInfo(fileName).FullName;
                }
                if (System.IO.File.Exists(dataFileName))
                {
                    return new FileInfo(dataFileName).FullName;
                }
                fileName = @"..\" + fileName;
                dataFileName = @"..\" + dataFileName;
            }

            return fileName;
        }
        #endregion

        /// <summary>
        /// Create a method for exit in file menuitem.
        /// </summary>
        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        #endregion

        private void Add_Click(object sender, EventArgs e)
        {
            Customers newData = new Customers();
            newData.Address = "Anna nagar";
            newData.City = "Chennai";
            newData.CompanyName = "Syncfusion";
            newData.ContactName = "Pavi";
            newData.CustomerID = "121";
            newData.ContactTitle = "Sales Rep";
            newData.Country = "India";
            newData.Fax = "234556";
            newData.Phone = "245678";
            newData.PostalCode = "625556";
            newData.Region = "chennai";
            customer.Add(newData);
            this.gridDataBoundGrid1.Refresh();
        }

        private void Delete_Click(object sender, EventArgs e)
        {
            customer.RemoveAt(1);
            this.gridDataBoundGrid1.Refresh();
        }
    }  

}